<?php

namespace Asadi\Fine\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Fine\Interfaces\FineRepositoryInterface;
use Asadi\Fine\Repositories\Presenter\FineItemTransformer;

/**
 * Pubic API controller class.
 */
class FinePublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Fine\Interfaces\FineRepositoryInterface $fine
     *
     * @return type
     */
    public function __construct(FineRepositoryInterface $fine)
    {
        $this->repository = $fine;
        parent::__construct();
    }

    /**
     * Show fine's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $fines = $this->repository
            ->setPresenter('\\Asadi\\Fine\\Repositories\\Presenter\\FineListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $fines['code'] = 2000;
        return response()->json($fines)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show fine.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $fine = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($fine)) {
            $fine         = $this->itemPresenter($module, new FineItemTransformer);
            $fine['code'] = 2001;
            return response()->json($fine)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
