<?php

namespace Asadi\Fine\Http\Controllers;
use Litepie\Fine\Http\Requests\FineRequest;
use Litepie\Fine\Models\Fine;

trait FineWorkflow {
	
    /**
     * Workflow controller function for fine.
     *
     * @param Model   $fine
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(FineRequest $request, Fine $fine, $step)
    {

        try {

            $fine->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('fine::fine.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/fine/fine/' . $fine->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/fine/fine/' . $fine->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for fine.
     *
     * @param Model   $fine
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Fine $fine, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $fine->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('fine::fine.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('fine::admin.fine.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('fine::admin.fine.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('fine::admin.fine.message', $data)->render();

        }

    }
}