<?php

namespace Asadi\Fine\Policies;

use App\User;
use Asadi\Fine\Models\Fine;

class FinePolicy
{

    /**
     * Determine if the given user can view the fine.
     *
     * @param User $user
     * @param Fine $fine
     *
     * @return bool
     */
    public function view(User $user, Fine $fine)
    {
        if ($user->canDo('fine.fine.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $fine->user_id;
    }

    /**
     * Determine if the given user can create a fine.
     *
     * @param User $user
     * @param Fine $fine
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('fine.fine.create');
    }

    /**
     * Determine if the given user can update the given fine.
     *
     * @param User $user
     * @param Fine $fine
     *
     * @return bool
     */
    public function update(User $user, Fine $fine)
    {
        if ($user->canDo('fine.fine.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $fine->user_id;
    }

    /**
     * Determine if the given user can delete the given fine.
     *
     * @param User $user
     * @param Fine $fine
     *
     * @return bool
     */
    public function destroy(User $user, Fine $fine)
    {
        if ($user->canDo('fine.fine.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $fine->user_id;
    }

    /**
     * Determine if the given user can verify the given fine.
     *
     * @param User $user
     * @param Fine $fine
     *
     * @return bool
     */
    public function verify(User $user, Fine $fine)
    {
        if ($user->canDo('fine.fine.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('fine.fine.verify') 
        && $user->is('manager')
        && $fine->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given fine.
     *
     * @param User $user
     * @param Fine $fine
     *
     * @return bool
     */
    public function approve(User $user, Fine $fine)
    {
        if ($user->canDo('fine.fine.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
