<?php

namespace Asadi\Fine\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Fine\Models\Fine;

class FineAction
{
    /**
     * Perform the complete action.
     *
     * @param Fine $fine
     *
     * @return Fine
     */
    public function complete(Fine $fine)
    {
        try {
            $fine->status = 'complete';
            return $fine->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Fine $fine
     *
     * @return Fine
     */public function verify(Fine $fine)
    {
        try {
            $fine->status = 'verify';
            return $fine->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Fine $fine
     *
     * @return Fine
     */public function approve(Fine $fine)
    {
        try {
            $fine->status = 'approve';
            return $fine->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Fine $fine
     *
     * @return Fine
     */public function publish(Fine $fine)
    {
        try {
            $fine->status = 'publish';
            return $fine->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Fine $fine
     *
     * @return Fine
     */
    public function archive(Fine $fine)
    {
        try {
            $fine->status = 'archive';
            return $fine->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Fine $fine
     *
     * @return Fine
     */
    public function unpublish(Fine $fine)
    {
        try {
            $fine->status = 'unpublish';
            return $fine->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
