<?php

namespace Asadi\Fine\Workflow;

use Asadi\Fine\Models\Fine;
use Validator;

class FineValidator
{

    /**
     * Determine if the given fine is valid for complete status.
     *
     * @param Fine $fine
     *
     * @return bool / Validator
     */
    public function complete(Fine $fine)
    {
        return Validator::make($fine->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given fine is valid for verify status.
     *
     * @param Fine $fine
     *
     * @return bool / Validator
     */
    public function verify(Fine $fine)
    {
        return Validator::make($fine->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given fine is valid for approve status.
     *
     * @param Fine $fine
     *
     * @return bool / Validator
     */
    public function approve(Fine $fine)
    {
        return Validator::make($fine->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given fine is valid for publish status.
     *
     * @param Fine $fine
     *
     * @return bool / Validator
     */
    public function publish(Fine $fine)
    {
        return Validator::make($fine->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given fine is valid for archive status.
     *
     * @param Fine $fine
     *
     * @return bool / Validator
     */
    public function archive(Fine $fine)
    {
        return Validator::make($fine->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given fine is valid for unpublish status.
     *
     * @param Fine $fine
     *
     * @return bool / Validator
     */
    public function unpublish(Fine $fine)
    {
        return Validator::make($fine->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
